@@ -27,7 +27,7 @@ class Handler(WSGIRequestHandler):
         try:
             super().handle_one_request()
         finally:
-            close_connection = True
+            self.close_connection = True
 
 
 class Server:
